@@ -6,9 +6,10 @@ Module concerned with alignment of diffraction images
 from functools import partial
 
 import numpy as np
+from warnings import warn
 from npstreams import array_stream
 from scipy import ndimage as ndi
-from skimage.feature import masked_register_translation, register_translation
+from skimage.registration import phase_cross_correlation
 
 
 @array_stream
@@ -51,11 +52,11 @@ def itrack_peak(images, row_slice=None, col_slice=None, precision=1 / 10):
 
     for image in images:
         sub[:] = image[row_slice, col_slice]
-        shift, *_ = register_translation(ref, sub, upsample_factor=int(1 / precision))
+        shift, *_ = phase_cross_correlation(reference_image=ref, moving_image=sub, upsample_factor=int(1 / precision))
         yield np.asarray(shift)
 
 
-def align(image, reference, mask=None, fill_value=0.0, fast=True):
+def align(image, reference, mask=None, fill_value=0.0, fast=None):
     """
     Align a diffraction image to a reference. Subpixel resolution available.
 
@@ -70,8 +71,7 @@ def align(image, reference, mask=None, fill_value=0.0, fast=True):
     fill_value : float, optional
         Edges will be filled with `fill_value` after alignment.
     fast : bool, optional
-        If True (default), alignment is done on images cropped to half
-        (one quarter area). Disable for small images, e.g. 256x256.
+        This parameter is deprecated, and has no effect.
     
     Returns
     -------
@@ -82,17 +82,22 @@ def align(image, reference, mask=None, fill_value=0.0, fast=True):
     --------
     ialign : generator of aligned images
     """
+    if fast is not None:
+        warn(
+            "skued.align: `fast` argument is deprecated and has no effect."
+        )
+
     if mask is None:
         mask = np.ones_like(image, dtype=np.bool)
 
-    shift = masked_register_translation(
-        src_image=image, target_image=reference, src_mask=mask
+    shift, *_ = phase_cross_correlation(
+        reference_image=image, moving_image=reference, reference_mask=mask
     )
     return ndi.shift(image, shift, order=2, mode="constant", cval=fill_value)
 
 
 @array_stream
-def ialign(images, reference=None, mask=None, fill_value=0.0, fast=True):
+def ialign(images, reference=None, mask=None, fill_value=0.0, fast=None):
     """
     Generator of aligned diffraction images.
 
@@ -109,8 +114,7 @@ def ialign(images, reference=None, mask=None, fill_value=0.0, fast=True):
     fill_value : float, optional
         Edges will be filled with `fill_value` after alignment.
     fast : bool, optional
-        If True (default), alignment is done on images cropped to half
-        (one quarter area). Disable for small images, e.g. 256x256.
+        This parameter is deprecated, and has no effect.
 
     Yields
     ------
@@ -121,6 +125,9 @@ def ialign(images, reference=None, mask=None, fill_value=0.0, fast=True):
     --------
     skued.align : align a single diffraction pattern onto a reference.
     """
+    if fast is not None:
+        warn("skued.ialign: `fast` argument is deprecated and has no effect.")
+
     images = iter(images)
 
     if reference is None:
@@ -128,10 +135,7 @@ def ialign(images, reference=None, mask=None, fill_value=0.0, fast=True):
         yield reference
 
     yield from map(
-        partial(
-            align, reference=reference, mask=mask, fill_value=fill_value, fast=fast
-        ),
-        images,
+        partial(align, reference=reference, mask=mask, fill_value=fill_value), images,
     )
 
 
