@@ -13,28 +13,34 @@ from scipy.special import k0 as bessel
 from .. import minimum_image_distance, repeated_array
 from .scattering_params import scattering_params
 
-m = 9.109*10**(-31)     #in kg
-a0 = 0.5291             #in Angs
-e = 14.4                #Volt*Angstrom
+m = 9.109 * 10 ** (-31)  # in kg
+a0 = 0.5291  # in Angs
+e = 14.4  # Volt*Angstrom
+
 
 def _electrostatic_atom(atom, r):
     try:
-        _, a1, b1, a2, b2, a3, b3, c1, d1, c2, d2, c3, d3 = scattering_params[atom.atomic_number]
+        _, a1, b1, a2, b2, a3, b3, c1, d1, c2, d2, c3, d3 = scattering_params[
+            atom.atomic_number
+        ]
     except KeyError:
-        raise ValueError('Scattering information for element {} is unavailable.'.format(atom.element))
+        raise ValueError(
+            f"Scattering information for element {atom.element} is unavailable."
+        )
 
-    sum1 = np.zeros_like(r, dtype = np.float)    
+    sum1 = np.zeros_like(r, dtype=np.float)
     for a, b in zip((a1, a2, a3), (b1, b2, b3)):
-        sum1 += a/r * np.exp(-2*pi*r*np.sqrt(b))
-    
+        sum1 += a / r * np.exp(-2 * pi * r * np.sqrt(b))
+
     sum2 = np.zeros_like(r, np.float)
     for c, d in zip((c1, c2, c3), (d1, d2, d3)):
-        sum2 += c * (d **(-1.5)) * np.exp( -(r*pi)**2 / d)
-    
-    e = 14.4                # [Volt-Angstrom]
-    a0 = 0.5291             # [Angs]
-    return 2*a0*e*(pi**2 * sum1 + pi**(2.5) * sum2)
-  
+        sum2 += c * (d ** (-1.5)) * np.exp(-((r * pi) ** 2) / d)
+
+    e = 14.4  # [Volt-Angstrom]
+    a0 = 0.5291  # [Angs]
+    return 2 * a0 * e * (pi ** 2 * sum1 + pi ** (2.5) * sum2)
+
+
 def electrostatic(crystal, x, y, z):
     """
     Electrostatic potential from a crystal calculated on a real-space mesh, 
@@ -42,7 +48,7 @@ def electrostatic(crystal, x, y, z):
 
     Parameters
     ----------
-    crystal : skued.Crystal
+    crystal : crystals.Crystal
         
     x, y, z : `~numpy.ndarray`
         Real space coordinates mesh. 
@@ -58,34 +64,43 @@ def electrostatic(crystal, x, y, z):
     """
     # TODO: split xx and yy into smalled non-repeating unit
     # TODO: multicore
-    
-    potential = np.zeros_like(x, dtype = np.float)
-    r = np.zeros_like(x, dtype = np.float)
+
+    potential = np.zeros_like(x, dtype=np.float)
+    r = np.zeros_like(x, dtype=np.float)
     for atom in crystal:
-        ax, ay, az = atom.xyz(crystal)
-        r[:] = minimum_image_distance(x - ax, y - ay, z - az, 
-                                        lattice = crystal.lattice_vectors)
+        ax, ay, az = atom.coords_cartesian
+        r[:] = minimum_image_distance(
+            x - ax, y - ay, z - az, lattice=crystal.lattice_vectors
+        )
         potential += _electrostatic_atom(atom, r)
-    
+
     # Due to sampling, x,y, and z might pass through the center of atoms
     # Replace np.inf by the next largest value
     m = potential[np.isfinite(potential)].max()
     potential[np.isinf(potential)] = m
     return potential
 
+
 def _pelectrostatic_atom(atom, r):
     try:
-        _, a1, b1, a2, b2, a3, b3, c1, d1, c2, d2, c3, d3 = scattering_params[atom.atomic_number]
+        _, a1, b1, a2, b2, a3, b3, c1, d1, c2, d2, c3, d3 = scattering_params[
+            atom.atomic_number
+        ]
     except KeyError:
-        raise ValueError('Scattering information for element {} is unavailable.'.format(atom.element))
-    
-    potential = np.zeros_like(r, dtype = np.float)
-    for a, b, c, d in zip((a1, a2, a3), (b1, b2, b3), (c1, c2, c3), (d1, d2, d3)):
-        potential += 2*a*bessel(2*pi*r*sqrt(b)) + (c/d) * np.exp( -(r*pi)**2 / d)
-    
-    return 2 * a0 * e * (pi**2) * potential
+        raise ValueError(
+            f"Scattering information for element {atom.element} is unavailable."
+        )
 
-def pelectrostatic(crystal, x, y, bounds = None):
+    potential = np.zeros_like(r, dtype=np.float)
+    for a, b, c, d in zip((a1, a2, a3), (b1, b2, b3), (c1, c2, c3), (d1, d2, d3)):
+        potential += 2 * a * bessel(2 * pi * r * sqrt(b)) + (c / d) * np.exp(
+            -((r * pi) ** 2) / d
+        )
+
+    return 2 * a0 * e * (pi ** 2) * potential
+
+
+def pelectrostatic(crystal, x, y, bounds=None):
     """
     Projected electrostatic potential from a crystal calculated on a real-space mesh, 
     assuming an infinite crystal in x and y. Projection axis is defined as the z-axis. 
@@ -93,7 +108,7 @@ def pelectrostatic(crystal, x, y, bounds = None):
 
     Parameters
     ----------
-    crystal : skued.Crystal
+    crystal : crystals.Crystal
         
     x, y:  `~numpy.ndarray`
         Real-space coordinates. 
@@ -116,17 +131,20 @@ def pelectrostatic(crystal, x, y, bounds = None):
 
     if bounds:
         min_z, max_z = min(bounds), max(bounds)
-        atoms = (atom for atom in iter(crystal) if min_z <= atom.xyz(crystal)[2] < max_z)
+        atoms = (
+            atom for atom in iter(crystal) if min_z <= atom.coords_cartesian[2] < max_z
+        )
     else:
         atoms = iter(crystal)
 
-    potential = np.zeros_like(x, dtype = np.float)
+    potential = np.zeros_like(x, dtype=np.float)
     z = np.zeros_like(x)
+    lattice = np.array(crystal.lattice_vectors)
     for atom in atoms:
-        xa, ya, _ = atom.xyz(crystal)
-        r = minimum_image_distance(x - xa, y - ya, z, lattice = np.array(crystal.lattice_vectors))
+        xa, ya, _ = atom.coords_cartesian
+        r = minimum_image_distance(x - xa, y - ya, z, lattice=lattice)
         potential += _pelectrostatic_atom(atom, r)
-    
+
     # Due to sampling, x,y, and z might pass through the center of atoms
     # Replace n.inf by the next largest value
     potential[np.isinf(potential)] = np.nan
